// ----------------------------------------------------------------------------
// Copyright (c) Microsoft Corporation.
// Licensed under the MIT license.
// ----------------------------------------------------------------------------

AppOwnsData.initializeEventHandlers = function () {

    // Radio button handle event
    $("input[type=radio]").on("click", function () {
        AppOwnsData.workspaceDefaultOption.selected = "true";

        // When report radio button is clicked
        if ($("#report").get(0).checked) {
            AppOwnsData.dashboardDiv.hide();
            AppOwnsData.tileDiv.hide();
            AppOwnsData.reportDiv.show();
            AppOwnsData.reportContainer.hide();
            AppOwnsData.reportDisplayText.show();
            AppOwnsData.dashboardWrapper.hide();
            AppOwnsData.tileWrapper.hide();
            $(".report-wrapper").removeClass("transparent-bg");
            $(".report-wrapper").addClass("colored-bg");
            AppOwnsData.reportWrapper.show();

            // Repopulate select list for report select event
            AppOwnsData.resetReportList();
            AppOwnsData.reportSelect.attr("disabled", "disabled");
        }

        // When dashboard radio button is clicked
        else if ($("#dashboard").get(0).checked) {
            AppOwnsData.reportDiv.hide();
            AppOwnsData.tileDiv.hide();
            AppOwnsData.dashboardDiv.show();
            AppOwnsData.dashboardContainer.hide();
            AppOwnsData.dashboardDisplayText.show();
            AppOwnsData.reportWrapper.hide();
            AppOwnsData.tileWrapper.hide();
            AppOwnsData.dashboardWrapper.show();

            // Repopulate select list for dashboard select event
            AppOwnsData.resetDashboardList();
            AppOwnsData.dashboardSelect.attr("disabled", "disabled");
        }

        // When radio button for tile is clicked
        else if ($("#tile").get(0).checked) {
            AppOwnsData.reportDiv.hide();
            AppOwnsData.dashboardDiv.show();
            AppOwnsData.tileDiv.show();
            AppOwnsData.tileContainer.hide();
            AppOwnsData.tileDisplayText.show();
            AppOwnsData.reportWrapper.hide();
            AppOwnsData.dashboardWrapper.hide();
            AppOwnsData.tileWrapper.show();

            // Repopulate select lists for tile select event
            AppOwnsData.resetDashboardList();
            AppOwnsData.resetTileList();
            AppOwnsData.dashboardSelect.attr("disabled", "disabled");
            AppOwnsData.tileSelect.attr("disabled", "disabled");
        }
    });

    // Workspace select event
    AppOwnsData.workspaceSelect.on("change", function () {
        let getSelectParams = {
            workspaceId: this.value
        };
        AppOwnsData.embedButton.attr("disabled", "disabled");

        // Populate select list
        if ($("#report").get(0).checked) {
            AppOwnsData.reportSelect.attr("disabled", "disabled");

            // Populate list of reports if report is checked
            AppOwnsData.resetReportList();
            AppOwnsData.getReports(getSelectParams);
        } else if ($("#dashboard").get(0).checked) {
            AppOwnsData.dashboardSelect.attr("disabled", "disabled");

            // Populate list of dashboards when dashboard radio is checked
            AppOwnsData.resetDashboardList();
            AppOwnsData.getDashboards(getSelectParams);
        } else {
            AppOwnsData.dashboardSelect.attr("disabled", "disabled");
            AppOwnsData.tileSelect.attr("disabled", "disabled");

            // Populate list of dashboards when tile radio is checked
            AppOwnsData.resetDashboardList();
            AppOwnsData.resetTileList();
            AppOwnsData.getDashboards(getSelectParams);
        }
    });

    // Report select event
    AppOwnsData.reportSelect.on("change", function () {
        AppOwnsData.embedButton.removeAttr("disabled");
    });

    // Dashboard select event
    AppOwnsData.dashboardSelect.on("change", function () {
        let getSelectParams = {
            accessToken: loggedInUser.accessToken,
            workspaceId: AppOwnsData.workspaceSelect.get(0).value
        };

        // Populate list of tiles after selecting the workspace from workspace list
        if ($("#tile").get(0).checked) {
            AppOwnsData.embedButton.attr("disabled", "disabled");
            AppOwnsData.tileSelect.attr("disabled", "disabled");
            AppOwnsData.resetTileList();
            getSelectParams.dashboardId = this.value;
            AppOwnsData.getTiles(getSelectParams);
        }

        // Enable embedButton when dashboard is selected
        else {
            AppOwnsData.embedButton.removeAttr("disabled");
        }
    });

    // Tile select event
    AppOwnsData.tileSelect.on("change", function () {
        AppOwnsData.embedButton.removeAttr("disabled");
    });

    // Embed content on button click
    AppOwnsData.embedButton.on("click", function () {
        let embedParam = {
            workspaceId: AppOwnsData.workspaceSelect.get(0).value
        };

        // Report radio button is checked
        if ($("#report").get(0).checked) {
            embedParam.reportId = AppOwnsData.reportSelect.get(0).value;

            // Embed report
            AppOwnsData.embedReport(embedParam);
        }

        // Dashboard radio button is checked
        else if ($("#dashboard").get(0).checked) {
            embedParam.dashboardId = AppOwnsData.dashboardSelect.get(0).value;

            // Embed dashboard
            AppOwnsData.embedDashboard(embedParam);
        }

        // Tile radio button is checked
        else if ($("#tile").get(0).checked) {
            embedParam.dashboardId = AppOwnsData.dashboardSelect.get(0).value;
            embedParam.tileId = AppOwnsData.tileSelect.get(0).value;

            // Embed tile
            AppOwnsData.embedTile(embedParam);
        }
        AppOwnsData.embedButton.attr("disabled", "disabled");
    });
}